@@ -53,33 +53,62 @@ struct _BraseroSessionSpanPrivate
 
 G_DEFINE_TYPE (BraseroSessionSpan, brasero_session_span, BRASERO_TYPE_BURN_SESSION);
 
-static goffset
-brasero_session_span_get_available_medium_space (BraseroSessionSpan *session)
+/**
+ * brasero_session_span_get_max_space:
+ * @session: a #BraseroSessionSpan
+ *
+ * Returns the maximum required space (in sectors) 
+ * among all the possible spanned batches.
+ * This means that when burningto a media
+ * it will also be the minimum required
+ * space to burn all the contents in several
+ * batches.
+ *
+ * Return value: a #goffset.
+ **/
+
+goffset
+brasero_session_span_get_max_space (BraseroSessionSpan *session)
 {
-	BraseroDrive *burner;
-	BraseroMedium *medium;
-	BraseroBurnFlag flags;
-	goffset available_blocks = 0;
+	GSList *tracks;
+	goffset max_sectors = 0;
+	BraseroSessionSpanPrivate *priv;
 
-	/* Retrieve the size available for burning */
-	burner = brasero_burn_session_get_burner (BRASERO_BURN_SESSION (session));
-	if (!burner)
-		return 0;
+	g_return_val_if_fail (BRASERO_IS_SESSION_SPAN (session), 0);
 
-	medium = brasero_drive_get_medium (burner);
-	if (!medium)
-		return 0;
+	priv = BRASERO_SESSION_SPAN_PRIVATE (session);
 
-	flags = brasero_burn_session_get_flags (BRASERO_BURN_SESSION (session));
-	if (flags & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND))
-		brasero_medium_get_free_space (medium, NULL, &available_blocks);
-	else if (brasero_burn_session_can_blank (BRASERO_BURN_SESSION (session)) == BRASERO_BURN_OK)
-		brasero_medium_get_capacity (medium, NULL, &available_blocks);
+	if (priv->last_track) {
+		tracks = g_slist_find (priv->track_list, priv->last_track);
+
+		if (!tracks->next)
+			return 0;
+
+		tracks = tracks->next;
+	}
+	else if (priv->track_list)
+		tracks = priv->track_list;
 	else
-		brasero_medium_get_free_space (medium, NULL, &available_blocks);
+		tracks = brasero_burn_session_get_tracks (BRASERO_BURN_SESSION (session));
 
-	BRASERO_BURN_LOG ("Available space for spanning %" G_GINT64_FORMAT, available_blocks);
-	return available_blocks;
+	for (; tracks; tracks = tracks->next) {
+		BraseroTrack *track;
+		goffset track_blocks = 0;
+
+		track = tracks->data;
+
+		if (BRASERO_IS_TRACK_DATA_CFG (track))
+			return brasero_track_data_cfg_span_max_space (BRASERO_TRACK_DATA_CFG (track));
+
+		/* This is the common case */
+		brasero_track_get_size (BRASERO_TRACK (track),
+					&track_blocks,
+					NULL);
+
+		max_sectors = MAX (max_sectors, track_blocks);
+	}
+
+	return max_sectors;
 }
 
 /**
@@ -153,7 +182,7 @@ brasero_session_span_possible (BraseroSessionSpan *session)
 
 	priv = BRASERO_SESSION_SPAN_PRIVATE (session);
 
-	max_sectors = brasero_session_span_get_available_medium_space (session);
+	max_sectors = brasero_burn_session_get_available_medium_space (BRASERO_BURN_SESSION (session));
 	if (max_sectors <= 0)
 		return BRASERO_BURN_ERR;
 
@@ -243,7 +272,7 @@ brasero_session_span_next (BraseroSessionSpan *session)
 
 	g_return_val_if_fail (priv->track_list != NULL, BRASERO_BURN_ERR);
 
-	max_sectors = brasero_session_span_get_available_medium_space (session);
+	max_sectors = brasero_burn_session_get_available_medium_space (BRASERO_BURN_SESSION (session));
 	if (max_sectors <= 0)
 		return BRASERO_BURN_ERR;
 
