@@ -239,7 +239,7 @@ brasero_audio_disc_is_empty (BraseroDisc *disc)
 
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (BRASERO_AUDIO_DISC (disc)->priv->tree));
 	if (!model)
-		return TRUE;
+		return FALSE;
 
 	return gtk_tree_model_iter_n_children (model, NULL) != 0;
 }
@@ -749,7 +749,8 @@ brasero_audio_disc_add_dir (BraseroAudioDisc *disc, const gchar *uri)
 				     GTK_MESSAGE_WARNING);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Directories cannot be added to an audio disc."));
+						  "%s.",
+						  _("Directories cannot be added to video or audio discs"));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -1973,10 +1974,10 @@ brasero_audio_disc_key_released_cb (GtkTreeView *tree,
 	if (disc->priv->editing)
 		return FALSE;
 
-	if (event->keyval == GDK_KP_Delete || event->keyval == GDK_Delete) {
+	if (event->keyval == GDK_KEY_KP_Delete || event->keyval == GDK_KEY_Delete) {
 		brasero_audio_disc_delete_selected (BRASERO_DISC (disc));
 	}
-	else if (event->keyval == GDK_F2)
+	else if (event->keyval == GDK_KEY_F2)
 		brasero_audio_disc_rename_activated (disc);
 
 	return FALSE;
